@@ -81,6 +81,8 @@ public:
 			column->pack_start(*label);
 			column->add_attribute(label->property_markup(), m_column.label);
 		}
+		m_treeview->signal_row_activated().connect(
+			sigc::mem_fun(*this, &TasksPage::on_row_activated));
 	}
 
 	/*
@@ -99,6 +101,13 @@ public:
 		}
 	}
 
+	/*
+	 */
+	void on_row_activated(const Gtk::TreeModel::Path &path, Gtk::TreeViewColumn *)
+	{
+		on_enabled_toggled(path.to_string());
+	}
+
 	/*
 	 *
 	 */
@@ -106,7 +115,7 @@ public:
 	{
 		Gtk::TreeIter it;
 		it = m_liststore->append();
-		(*it)[m_column.enabled] = page->is_visible();
+		(*it)[m_column.enabled] = page->is_enable();
 		(*it)[m_column.label] = Glib::ustring::compose("<b>%1</b>\n%2", page->get_page_label(), page->get_page_description());
 		(*it)[m_column.page] = page;
 	}
