@@ -24,10 +24,7 @@
  */
  
 
-#include <gtkmm/window.h>
-#include <gtkmm/notebook.h>
-#include <gtkmm/box.h>
-
+#include <gtkmm.h>
 #include "document.h"
 #include "menubar.h"
 #include "statusbar.h"
@@ -89,6 +86,7 @@ protected:
 	 */
 	void 	notebook_drag_data_received (const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time);
 	void 	player_drag_data_received (const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time);
+	void 	waveform_drag_data_received (const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time);
 
 	/*
 	 *
@@ -119,7 +117,7 @@ protected:
 	 *	Changement dans le notebook de la page editer
 	 *	On recupere la page pusi on init DocumentSystem avec le document
 	 */
-	void on_signal_switch_page(GtkNotebookPage* page, guint page_num);
+	void on_signal_switch_page(Gtk::Widget* page, guint page_num);
 
 	/*
 	 *
@@ -163,10 +161,13 @@ protected:
 
 	void update_title(Document *doc);
 
+	void load_window_state();
+	void save_window_sate();
 protected:
-	Gtk::VBox*			m_vboxMain;
+	Gtk::Box*				m_vboxMain;
 	MenuBar					m_menubar;
-	Gtk::HPaned*		m_paned_multimedia;
+	Gtk::Paned*			m_paned_main;
+	Gtk::Paned*			m_paned_multimedia;
 	VideoPlayer*		m_video_player;
 	WaveformEditor*	m_waveform_editor;
 	Gtk::Notebook*	m_notebook_documents;
