@@ -23,11 +23,12 @@
 #include "comboboxvideo.h"
 #include "cfg.h"
 #include "i18n.h"
+#include "comboboxtextcolumns.h"
 
 /*
  * Constructor
  */
-ComboBoxVideo::ComboBoxVideo(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+ComboBoxVideo::ComboBoxVideo(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /*builder*/)
 :Gtk::ComboBoxText(cobject)
 {
 	// separator function
@@ -40,37 +41,39 @@ ComboBoxVideo::ComboBoxVideo(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Bu
  */
 bool ComboBoxVideo::set_current_folder(const Glib::ustring &path)
 {
-	clear();
+	remove_all();
 
 	Glib::Dir dir(path);
 	std::vector<std::string> files(dir.begin(), dir.end());
 
+	// No files in the directory, unsensitive the widget
 	if(files.empty())
 	{
 		set_sensitive(false);
 		return false;
 	}
 
+	// Try to find video files
 	Glib::RefPtr<Glib::Regex> re = Glib::Regex::create(
 			"^(.*)\\.((avi)|(wma)|(mkv)|(mpg)|(mpeg)|(ogg)|(mov)|(mp4)|(xvid))$");
-		
+
 	for(unsigned int i=0; i<files.size(); ++i)
 	{
 		if(re->match(files[i]))
-			append_text(files[i]);
+			append(files[i]);
 	}
 
+	// Not found? unsensitive the widget
 	if(get_model()->children().size() == 0)
 	{
 		set_sensitive(false);
 		return false;
 	}
-	
+
 	set_sensitive(true);
 
-	prepend_text("<separator>");
-	prepend_text(_("None"));
-
+	prepend("<separator>", "");
+	prepend(_("None"));
 	return true;
 }
 
@@ -83,7 +86,10 @@ bool ComboBoxVideo::auto_select_video(const Glib::ustring &subtitle)
 	if(get_model()->children().empty())
 		return false;
 
-	if(Config::getInstance().get_value_bool("video-player", "automatically-open-video") == false)
+	bool is_directory_or_empty = (Glib::file_test(subtitle, Glib::FILE_TEST_IS_DIR) || subtitle.empty());
+	bool is_automatically_open_video = Config::getInstance().get_value_bool("video-player", "automatically-open-video");
+
+	if(is_directory_or_empty || is_automatically_open_video == false)
 	{
 		set_active(0);
 		return false;
@@ -93,13 +99,15 @@ bool ComboBoxVideo::auto_select_video(const Glib::ustring &subtitle)
 			"^(.*)\\.((avi)|(wma)|(mkv)|(mpg)|(mpeg)|(ogg)|(mov)|(mp4)|(xvid))$");
 
 	Gtk::TreeIter it = get_model()->children().begin();
+	ComboBoxTextColumns cols;
 
 	for(; it; ++it)
 	{
-		Glib::ustring video = (*it)[m_text_columns.m_column];
+		Glib::ustring video = (*it)[cols.m_col_name];
+		if(video.empty())
+			continue;
 
 		std::vector<Glib::ustring> group = re->split(video);
-
 		if(group.size() == 1)
 			continue;
 
@@ -109,10 +117,8 @@ bool ComboBoxVideo::auto_select_video(const Glib::ustring &subtitle)
 			return true;
 		}
 	}
-
 	// not found, active "None"
 	set_active(0);
-
 	return false;
 }
 
@@ -131,10 +137,10 @@ Glib::ustring ComboBoxVideo::get_value() const
  * Used to define the separator.
  * label = "<separator>"
  */
-bool ComboBoxVideo::on_row_separator_func(const Glib::RefPtr<Gtk::TreeModel> &model, const Gtk::TreeModel::iterator &it)
+bool ComboBoxVideo::on_row_separator_func(const Glib::RefPtr<Gtk::TreeModel> &/*model*/, const Gtk::TreeModel::iterator &it)
 {
-	Glib::ustring text = (*it)[m_text_columns.m_column];
-	if(text == "<separator>")
+	ComboBoxTextColumns cols;
+	if( (*it)[cols.m_col_id] == "<separator>")
 		return true;
 	return false;
 }
