@@ -32,8 +32,6 @@
 DialogCharacterCodings::DialogCharacterCodings(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 :Gtk::Dialog(cobject)
 {
-	utility::set_transient_parent(*this);
-
 	builder->get_widget("treeview-available", treeviewAvailable);
 	builder->get_widget("treeview-displayed", m_treeviewDisplayed);
 	builder->get_widget("button-add", m_buttonAdd);
@@ -132,9 +130,11 @@ void DialogCharacterCodings::init_encodings_available()
 
 	m_storeAvailable = Gtk::ListStore::create(m_column);
 
-	for(unsigned int i=0; encodings_info[i].charset != NULL; ++i)
+	EncodingInfo* ei = Encodings::get_encodings_info();
+
+	for(unsigned int i=0; ei[i].charset != NULL; ++i)
 	{
-		append_encoding(m_storeAvailable, encodings_info[i].charset);
+		append_encoding(m_storeAvailable, ei[i].charset);
 	}
 	
 	m_storeAvailable->set_sort_column(m_column.description, Gtk::SORT_ASCENDING);
@@ -211,11 +211,11 @@ void DialogCharacterCodings::on_button_remove()
 {
 	std::vector<Gtk::TreeModel::Path> rows;
 
-	Glib::RefPtr<Gtk::TreeSelection> selection =  m_treeviewDisplayed->get_selection();
+	rows = m_treeviewDisplayed->get_selection()->get_selected_rows();
 
-	while(!(rows = selection->get_selected_rows()).empty())
+	for(std::vector<Gtk::TreeModel::Path>::reverse_iterator iter = rows.rbegin(); iter!= rows.rend(); ++iter)
 	{
-		Gtk::TreeIter it = m_storeDisplayed->get_iter(rows[0]);
+		Gtk::TreeIter it = m_storeDisplayed->get_iter(*iter);
 		m_storeDisplayed->erase(it);
 	}
 }
@@ -270,7 +270,7 @@ void DialogCharacterCodings::on_response(int id)
 /*
  * Add the selected charset.
  */
-void DialogCharacterCodings::on_row_available_activated(const Gtk::TreeModel::Path &path, Gtk::TreeViewColumn *column)
+void DialogCharacterCodings::on_row_available_activated(const Gtk::TreeModel::Path &path, Gtk::TreeViewColumn * /*column*/)
 {
 	Gtk::TreeIter it = m_storeAvailable->get_iter(path);
 	if(it)
@@ -284,7 +284,7 @@ void DialogCharacterCodings::on_row_available_activated(const Gtk::TreeModel::Pa
 /*
  * Remove the selected charset.
  */
-void DialogCharacterCodings::on_row_displayed_activated(const Gtk::TreeModel::Path &path, Gtk::TreeViewColumn *column)
+void DialogCharacterCodings::on_row_displayed_activated(const Gtk::TreeModel::Path &path, Gtk::TreeViewColumn * /*column*/)
 {
 	Gtk::TreeIter it = m_storeDisplayed->get_iter(path);
 	if(it)
@@ -296,13 +296,13 @@ void DialogCharacterCodings::on_row_displayed_activated(const Gtk::TreeModel::Pa
  * Create an instance of the dialog .ui file)
  * If the response is OK the config is saved.
  */
-std::auto_ptr<DialogCharacterCodings> DialogCharacterCodings::create()
+std::auto_ptr<DialogCharacterCodings> DialogCharacterCodings::create(Gtk::Window &parent)
 {
 	std::auto_ptr<DialogCharacterCodings> ptr(
 			gtkmm_utility::get_widget_derived<DialogCharacterCodings>(
 				SE_DEV_VALUE(PACKAGE_UI_DIR, PACKAGE_UI_DIR_DEV),
 				"dialog-character-codings.ui", 
 				"dialog-character-codings") );
-
+	ptr->set_transient_for(parent);
 	return ptr;
 }
